searchData={"items":[{"type":"module","title":"Json5","doc":"Convert Json5 to Elixir term and back","ref":"Json5.html"},{"type":"function","title":"Json5.decode/2","doc":"parse json5 input as elixir type.\n\nTo keep the precision of the given numbers the integers and floats are cast to `Decimal`\n\noptions:\n- object_key_function: (binary) -> any\n  - use given function to format the object key\n- object_key_existing_atom: boolean\n  - format the object key with `String.to_existing_atom/1`\n- object_key_atom: boolean\n  - format the object key with `String.to_atom/1`\n  - if none of the above options are set return the key as a binary (String.t())\n- object_new_function: ({any, any}) -> any\n  - function to create a map from the list of parsed tuples, by default uses `Map.new/1`\n- backend: [`Json5.Decode.Backend.Combine`, `Json5.Decode.Backend.Yecc`]\n  - select the backend to be used (Defaults to Combine). \n  - The Combine backend is coded with the json5 spec (with unicode) in mind, but a lot slower (about 2000x slower than `Jason`)\n  - The Yecc backend is a lot faster (about 6x slower than `Jason`) but not that rigorous based on the json5 spec. It is just written to make the existing tests work.\n\n```elixir\niex> Json5.decode(\"{array: [1, 2, 3], map: {'null': null, test: 1, }, }\")\n{:ok, %{\n  \"map\" => %{\n    \"test\" => Decimal.new(1), \n    \"null\" => nil\n  }, \n  \"array\" => [\n    Decimal.new(1), \n    Decimal.new(2), \n    Decimal.new(3)\n  ]\n}}\n```","ref":"Json5.html#decode/2"},{"type":"function","title":"Json5.decode!/2","doc":"Same as `decode/2` but raises on error","ref":"Json5.html#decode!/2"},{"type":"function","title":"Json5.encode/2","doc":"Encode elixir input as json5. Contains some simple formatting options\n\noptions:\n  - pretty: boolean\n  - compact: boolean\n\n\n```elixir\niex> Json5.encode(%{map: %{test: 1, null: nil}, array: [1,2,3]})\n{:ok, \"{array: [1, 2, 3], map: {'null': null, test: 1, }, }\"}\niex> Json5.encode(%{map: %{test: 1, null: nil}, array: [1,2,3]}, pretty: true)\n{:ok, \"\"\"\n  {\n    array: [\n      1,\n      2,\n      3,\n    ],\n    map: {\n      'null': null,\n      test: 1,\n    },\n  }\n  \"\"\"}\niex> Json5.encode(%{map: %{test: 1, null: nil}, array: [1,2,3]}, compact: true)\n{:ok, \"{array:[1,2,3],map:{'null':null,test:1}}\"}\n```","ref":"Json5.html#encode/2"},{"type":"function","title":"Json5.encode!/2","doc":"Same as `encode/2` but raises on error","ref":"Json5.html#encode!/2"},{"type":"module","title":"Json5.Decode","doc":"Decode Json5 string to Elixir term","ref":"Json5.Decode.html"},{"type":"function","title":"Json5.Decode.parse/2","doc":"","ref":"Json5.Decode.html#parse/2"},{"type":"module","title":"Json5.Decode.Backend.Combine","doc":"Decode Json5 string to Elixir term","ref":"Json5.Decode.Backend.Combine.html"},{"type":"function","title":"Json5.Decode.Backend.Combine.json5_value/2","doc":"","ref":"Json5.Decode.Backend.Combine.html#json5_value/2"},{"type":"function","title":"Json5.Decode.Backend.Combine.parse/2","doc":"","ref":"Json5.Decode.Backend.Combine.html#parse/2"},{"type":"function","title":"Json5.Decode.Backend.Combine.parser/1","doc":"","ref":"Json5.Decode.Backend.Combine.html#parser/1"},{"type":"module","title":"Json5.Decode.Backend.Combine.Array","doc":"Documentation for `Json5`.","ref":"Json5.Decode.Backend.Combine.Array.html"},{"type":"function","title":"Json5.Decode.Backend.Combine.Array.array/0","doc":"","ref":"Json5.Decode.Backend.Combine.Array.html#array/0"},{"type":"module","title":"Json5.Decode.Backend.Combine.Boolean","doc":"Documentation for `Json5`.","ref":"Json5.Decode.Backend.Combine.Boolean.html"},{"type":"function","title":"Json5.Decode.Backend.Combine.Boolean.boolean/0","doc":"","ref":"Json5.Decode.Backend.Combine.Boolean.html#boolean/0"},{"type":"module","title":"Json5.Decode.Backend.Combine.Helper","doc":"General helper functions","ref":"Json5.Decode.Backend.Combine.Helper.html"},{"type":"function","title":"Json5.Decode.Backend.Combine.Helper.ecma_line_terminator/0","doc":"","ref":"Json5.Decode.Backend.Combine.Helper.html#ecma_line_terminator/0"},{"type":"function","title":"Json5.Decode.Backend.Combine.Helper.ignore_whitespace/1","doc":"","ref":"Json5.Decode.Backend.Combine.Helper.html#ignore_whitespace/1"},{"type":"function","title":"Json5.Decode.Backend.Combine.Helper.ignored_comma/1","doc":"","ref":"Json5.Decode.Backend.Combine.Helper.html#ignored_comma/1"},{"type":"macro","title":"Json5.Decode.Backend.Combine.Helper.is_line_terminator/1","doc":"","ref":"Json5.Decode.Backend.Combine.Helper.html#is_line_terminator/1"},{"type":"function","title":"Json5.Decode.Backend.Combine.Helper.lazy/2","doc":"","ref":"Json5.Decode.Backend.Combine.Helper.html#lazy/2"},{"type":"function","title":"Json5.Decode.Backend.Combine.Helper.lazy_json5_value/0","doc":"","ref":"Json5.Decode.Backend.Combine.Helper.html#lazy_json5_value/0"},{"type":"function","title":"Json5.Decode.Backend.Combine.Helper.multi_line_comment/0","doc":"","ref":"Json5.Decode.Backend.Combine.Helper.html#multi_line_comment/0"},{"type":"function","title":"Json5.Decode.Backend.Combine.Helper.remove_white_space/0","doc":"","ref":"Json5.Decode.Backend.Combine.Helper.html#remove_white_space/0"},{"type":"function","title":"Json5.Decode.Backend.Combine.Helper.single_line_comment/0","doc":"","ref":"Json5.Decode.Backend.Combine.Helper.html#single_line_comment/0"},{"type":"module","title":"Json5.Decode.Backend.Combine.Null","doc":"Documentation for `Json5`.","ref":"Json5.Decode.Backend.Combine.Null.html"},{"type":"function","title":"Json5.Decode.Backend.Combine.Null.null/0","doc":"","ref":"Json5.Decode.Backend.Combine.Null.html#null/0"},{"type":"module","title":"Json5.Decode.Backend.Combine.Number","doc":"Documentation for `Json5`.","ref":"Json5.Decode.Backend.Combine.Number.html"},{"type":"function","title":"Json5.Decode.Backend.Combine.Number.ecma_decimal_literal/0","doc":"","ref":"Json5.Decode.Backend.Combine.Number.html#ecma_decimal_literal/0"},{"type":"function","title":"Json5.Decode.Backend.Combine.Number.ecma_decimal_literal_1/0","doc":"","ref":"Json5.Decode.Backend.Combine.Number.html#ecma_decimal_literal_1/0"},{"type":"function","title":"Json5.Decode.Backend.Combine.Number.ecma_decimal_literal_2/0","doc":"","ref":"Json5.Decode.Backend.Combine.Number.html#ecma_decimal_literal_2/0"},{"type":"function","title":"Json5.Decode.Backend.Combine.Number.ecma_decimal_literal_3/0","doc":"","ref":"Json5.Decode.Backend.Combine.Number.html#ecma_decimal_literal_3/0"},{"type":"function","title":"Json5.Decode.Backend.Combine.Number.number/0","doc":"","ref":"Json5.Decode.Backend.Combine.Number.html#number/0"},{"type":"module","title":"Json5.Decode.Backend.Combine.Object","doc":"Documentation for `Json5`.","ref":"Json5.Decode.Backend.Combine.Object.html"},{"type":"function","title":"Json5.Decode.Backend.Combine.Object.object/1","doc":"","ref":"Json5.Decode.Backend.Combine.Object.html#object/1"},{"type":"module","title":"Json5.Decode.Backend.Combine.String","doc":"Documentation for `Json5`.","ref":"Json5.Decode.Backend.Combine.String.html"},{"type":"function","title":"Json5.Decode.Backend.Combine.String.string/0","doc":"","ref":"Json5.Decode.Backend.Combine.String.html#string/0"},{"type":"module","title":"Json5.Decode.Backend.Yecc","doc":"Decode Json5 string to Elixir term\n\nDoes not support unicode map keys","ref":"Json5.Decode.Backend.Yecc.html"},{"type":"function","title":"Json5.Decode.Backend.Yecc.do_key_term/2","doc":"","ref":"Json5.Decode.Backend.Yecc.html#do_key_term/2"},{"type":"function","title":"Json5.Decode.Backend.Yecc.parse/2","doc":"","ref":"Json5.Decode.Backend.Yecc.html#parse/2"},{"type":"module","title":"Json5.ECMA","doc":"Defines some ECMA constants","ref":"Json5.ECMA.html"},{"type":"function","title":"Json5.ECMA.ecma_identifier_name/0","doc":"","ref":"Json5.ECMA.html#ecma_identifier_name/0"},{"type":"macro","title":"Json5.ECMA.is_reserved_word/1","doc":"","ref":"Json5.ECMA.html#is_reserved_word/1"},{"type":"function","title":"Json5.ECMA.reserved_word?/1","doc":"","ref":"Json5.ECMA.html#reserved_word?/1"},{"type":"function","title":"Json5.ECMA.reserved_words/0","doc":"","ref":"Json5.ECMA.html#reserved_words/0"},{"type":"function","title":"Json5.ECMA.valid_identifier?/1","doc":"","ref":"Json5.ECMA.html#valid_identifier?/1"},{"type":"module","title":"Json5.Encode","doc":"Encode Elixir term to Json5 string","ref":"Json5.Encode.html"},{"type":"function","title":"Json5.Encode.do_dump/2","doc":"","ref":"Json5.Encode.html#do_dump/2"},{"type":"function","title":"Json5.Encode.dump/2","doc":"","ref":"Json5.Encode.html#dump/2"},{"type":"module","title":"Json5.Encode.Array","doc":"Documentation for `Json5`.","ref":"Json5.Encode.Array.html"},{"type":"function","title":"Json5.Encode.Array.dump/2","doc":"","ref":"Json5.Encode.Array.html#dump/2"},{"type":"module","title":"Json5.Encode.Object","doc":"Documentation for `Json5`.","ref":"Json5.Encode.Object.html"},{"type":"function","title":"Json5.Encode.Object.dump/2","doc":"","ref":"Json5.Encode.Object.html#dump/2"},{"type":"exception","title":"Json5.Error","doc":"","ref":"Json5.Error.html"}],"content_type":"text/markdown","producer":{"name":"ex_doc","version":[48,46,51,52,46,48]}}